#
# spec file for package barrel
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           barrel
Version:        0.2.8
Release:        1.3
Summary:        Tool for storage management
License:        GPL-2.0-only
Group:          System/Packages
URL:            https://github.com/openSUSE/barrel
Source:         barrel-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  libstorage-ng-devel >= 4.5.101
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  readline-devel

Requires:       libstorage-ng1 >= 4.5.101
Recommends:     %{name}-lang
Recommends:     logrotate
%if 0%{?fedora_version}
BuildRequires:  boost-devel
BuildRequires:  docbook-style-xsl
BuildRequires:  json-c-devel
%else
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libboost_headers-devel
BuildRequires:  libboost_test-devel
BuildRequires:  libjson-c-devel
%endif

%description
barrel is a command line tool for storage management.

%prep
%setup -q

%build
export CFLAGS="%{optflags} -DNDEBUG"
export CXXFLAGS="%{optflags} -DNDEBUG"

autoreconf -fvi
%configure \
    --docdir="%{_docdir}/%{name}"
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check VERBOSE=1

%install
%make_install

%fdupes -s %{buildroot}

%find_lang barrel

%files
%defattr(-,root,root)
%{_sbindir}/barrel
%dir %{_sysconfdir}/barrel
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/AUTHORS
%doc %{_mandir}/*/barrel.8*
%config(noreplace) %{_sysconfdir}/logrotate.d/barrel
%license %{_docdir}/%{name}/LICENSE

%package lang
Summary:        Languages for package %{name}
Group:          System/Localization
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%files lang -f barrel.lang

%changelog
* Tue Jul 16 2024 aschnell@suse.com
- support more encryption options
- version 0.2.8
* Thu May  2 2024 aschnell@suse.com
- fix build with gcc14
- version 0.2.7
* Fri Mar 15 2024 aschnell@suse.com
- mark inactive mount points
* Mon Feb  5 2024 aschnell@suse.com
- follow renumbering of partitions during remove
  (gh#openSUSE/snapper#85)
- version 0.2.6
* Mon Jan 29 2024 aschnell@suse.com
- experimental support for bcachefs
* Tue Jan  2 2024 aschnell@suse.com
- speedup startup
- version 0.2.5
* Wed Oct 11 2023 aschnell@suse.com
- support RAID level LINEAR
- version 0.2.4
* Fri Oct  6 2023 aschnell@suse.com
- allow to use a key file when creating an encryption device
- version 0.2.3
* Thu Sep 21 2023 aschnell@suse.com
- allow to not add file systems in /etc/fstab
- version 0.2.2
* Wed May 31 2023 aschnell@suse.com
- handle unsupported partition ids during loading of devicegraph
- version 0.2.1
* Mon Mar 13 2023 aschnell@suse.com
- colorize output
- version 0.2.0
* Tue Jan 17 2023 aschnell@suse.com
- allow both 'swap' and 'none' as path for swap
- version 0.1.9
* Tue Oct 18 2022 aschnell@suse.com
- set more specific partitions ids (e.g. home, srv) if possible
- version 0.1.8
* Thu Aug  4 2022 aschnell@suse.com
- support arrays on stack and use of arrays when creating volume
  groups and file systems
- version 0.1.7
* Tue Jul  5 2022 aschnell@suse.com
- allow to create multi-device btrfs
- version 0.1.6
* Thu Jun  9 2022 aschnell@suse.com
- show btrfs profiles
- version 0.1.5
* Fri May 27 2022 aschnell@suse.com
- support activation of LUKS and BitLocker
- version 0.1.4
* Mon May  9 2022 aschnell@suse.com
- added nilfs2 support
- version 0.1.3
* Thu May  5 2022 aschnell@suse.com
- added logging
- version 0.1.2
* Mon Mar 21 2022 aschnell@suse.com
- added aliases exfat and vfat
- version 0.1.1
* Mon Mar  7 2022 aschnell@suse.com
- updated translations
* Fri Jan 21 2022 aschnell@suse.com
- without providing the MD RAID metadata version use the default
  of mdadm
- version 0.1.0
* Thu Dec  2 2021 aschnell@suse.com
- handle multipath and DM RAID during loading of devicegraph
- version 0.0.8
* Tue Nov 23 2021 aschnell@suse.com
- added command 'show tree' to show tree of devices
- version 0.0.7
* Tue Nov 16 2021 aschnell@suse.com
- handle multibyte sequences in tables
- version 0.0.6
* Tue Nov  9 2021 aschnell@suse.com
- initial packaging for openSUSE
- version 0.0.5
